Title: Necessity and Warrant
Date: 2020-03-30
Author: namespace
Category: Essay

<blockquote>
<i>Literary warrant</i>, a concept introduced by Wyndam Hulme in 1911, has the status of a principle. A subprinciple of the principle of representation, it enjoins that the vocabulary of a subject language be empirically derived from the literature it is intended to describe. This means that a literature must be determined. For Hulme, the language in question was the Library of Congress Classification (LCC), and the literature that served as warrant were the books housed in the Library of Congress. For a discipline-specific language, the literature might be defined as the canonical texts in the discipline or as the core set of documents of the discipline, as this is determined by citation frequency. Once the literature of a discipline is defined, then expressions in it indicative of aboutness become candidates for inclusion in the vocabulary of the language.
<br><br>&nbsp;&nbsp;&nbsp;&nbsp;— Elaine Svenonius, <i>The Intellectual Foundation Of Information Organization</i>
</blockquote>

[In the previous post](https://thelastrationalist.com/on-necessity.html)
I discussed the concept of phenomenological necessity. Reality has a consistent
ruleset on which we can base reasoning. Our expectations about reality should be
based on rules and sense-data derived from reality. The extreme consistency of physics
is one of the most important revelations of the 20th century: while our world is dizzying
in its complexity and [anti-inductive in its presentation](https://slatestarcodex.com/2015/01/11/the-phatic-and-the-anti-inductive/)
the underlying principles are comparatively simple: 

<blockquote>
The vision I got from Democritus was of a God who was single-mindedly obsessed with enforcing a couple of rules about certain types of information you are not allowed to have under any circumstances. Some of these rules I’d already known about. You can’t have information from outside your light cone. You can’t have information about the speed and position of a particle at the same time. Others I hadn’t thought about as much until reading Democritus. Information about when a Turing machine will halt. Information about whether certain formal systems are consistent. Precise information about the quantum state of a particle. The reason God hasn’t solved world poverty yet is that He is pacing about feverishly worried that someone, somewhere, is going to be able to measure the quantum state of a particle too precisely, and dreaming up new and increasingly bizarre ways He can prevent that from happening.
<br><br>&nbsp;&nbsp;&nbsp;&nbsp;— Scott Alexander, <i><a href="https://slatestarcodex.com/2014/09/01/book-review-and-highlights-quantum-computing-since-democritus/">Book Review and Highlights: Quantum Computing Since Democritus</a></i>
</blockquote>

<blockquote>
Okay, Bayes-Goggles back on. Are you really going to believe that large parts of the wavefunction disappear when you can no longer see them? As a result of the only non-linear non-unitary non-differentiable non-CPT-symmetric acausal faster-than-light informally-specified phenomenon in all of physics? Just because, by sheer historical contingency, the stupid version of the theory was proposed first?
<br><br>&nbsp;&nbsp;&nbsp;&nbsp;— Eliezer Yudkowsky,<i><a href="https://www.readthesequences.com/The-Dilemma-Science-Or-Bayes">The Dilemma: Science or Bayes?</a></i>
</blockquote>

The complexity that arises from these 'simple' rules leads to uncertainty, and that uncertainty makes the world
unpredictable and difficult for our minds to make sense of. We might imagine ourselves in a maze, carefully mapping
our environment. As better patterns come along that predict the maze with increasing accuracy and economy of expression
 we manage to put more and more of the maze into a smaller and smaller representation. But as the representation
becomes smaller, the work necessary to unpack it into the territory we're interested in increases. [It's difficult to
model most real world systems just by knowing their underlying physics](https://www.xkcd.com/793/). The complexity
of how reality expresses itself forces us to rely on abstractions, mental models, and approximations. There's no easy
way to know everything about anything. This means that *which* questions and forms of knowledge we choose to acquire is
just as important as any reasoning techniques we use to deal with them. 

A good example of this can be found in the book *Evangelism Explosion* by D. James Kennedy. Written with the goal of making
modern Christian churches see exponential growth, the author shares (at length and in detail) exactly how he goes about witnessing
Christ to others and teaching Christians to witness. What's striking about it is that before he attempts to share the gospel, he
makes a point of [asking two questions](https://evangelismexplosion.org/the-two-question/) to set up the conversation: Whether the
target knows they'll be with god after they die and what they'd say if god asked them why he should let them in. The thing I find
so interesting about this is that [he opens with a Christian frame](https://en.wikipedia.org/wiki/Framing_(social_sciences)), and
mostly seems to ignore the possibility that you might encounter an atheist or even a Hindu.

The script itself is simple, seemingly just a positive presentation of the basic
idea that eternal life can be yours if you give up your mind and body to Christ.
I found this so shocking that I stopped reading and asked an apostate if this stuff really worked, and he informed me that it did.
I'd always thought of Evangelists as being out to convert non-Christians, but if I'm to take what I read from them seriously the 
goal is mostly to take weak Christian theists and turn them into strong Christian theists. By the time you're willing to engage with
a question like "Will you be with god in heaven after you die?" you're already most of the way to being a Christian. Imagine this same
conversation with an atheist, who would say "Woah woah back up, who says this 'god' character exists? Why do you think that?". If engaging
with someone's questions about god takes you most of the way to being Christian, it should be obvious that letting other people ask you
questions without justification takes you most of the way to believing whatever they want you to believe.

Eliezer Yudkowsky discusses this problem frequently in his *Rationality: AI to Zombies*. Most notable is his essay
on [privileging the hypothesis](https://www.readthesequences.com/Privileging-The-Hypothesis), where he tries to get across
a similar idea. There Eliezer imagines numbering every possible hypothesis in a scenario from one to some very large number 
like 4 billion. He then uses the basic principles of [information theory](https://en.wikipedia.org/wiki/Information_theory) to show
that taking a question without justification is to skip over the vast majority of possibilities. Remember that only one hypothesis
is the truth, so to do this without care risks excluding the correct answer from consideration before we've even begun to analyze
things. Unfortunately, I didn't understand what he meant on my first read, because I wasn't very familiar with computer science. 

This idea is of extreme importance, so it's worth explaining in detail. To keep it simple, lets go back to that notion of numbering
every hypothesis above noise from one to 4 billion. It takes a certain amount of *information* to represent this number. The standard
unit of information in computer science is of course the binary digit (bit), a one or a zero. A single bit has two possibilities, 1 or 0.
Two bits in sequence can be combined four ways: 00,01,10,11. If we add a third bit, you will find there are eight combinations. In fact,
each added bit allows us to represent twice the number of combinations. By the time we have put together 32 bits, we can represent 4 billion
possibilities. As we gain information about a problem, we (hopefully) narrow in on the correct point in this sea of hypothesis. To ask a question
that narrows us down to say, 10 possibilities, is to assert that we have already collected the vast majority of information, or the majority of
bits necessary to represent our choice in this domain. If you consider a question merely because the question has been asked, you are allowing other
people to choose most of your beliefs for you.

We can call this notion of whether or not a question is justified *warrant*, in the same sense that the police 
need a *warrant* before they can search a US citizens house. If necessity asks "Is this a reasonable expectation?", warrant asks "Why are(n't) we 
considering this question?". The [just world fallacy](https://en.wikipedia.org/wiki/Just-world_hypothesis),
[denial of death](https://www.thelastrationalist.com/memento-mori-said-the-confessor.html), and 
[postmodernism](https://en.wikipedia.org/wiki/Postmodernism) are failures of necessity. [Privileging the hypothesis](https://www.readthesequences.com/Privileging-The-Hypothesis), 
[confirmation bias](https://en.wikipedia.org/wiki/Confirmation_bias), and [the base rate fallacy](https://en.wikipedia.org/wiki/Base_rate_fallacy) are failures of warrant. Together, warrant and necessity form the "punch and kick" of rationality, basic foundational moves which must be 
practiced and mastered before it's possible to reliably execute more advanced technique.

Necessity and warrant go together, because to get good at using necessity we have to
manage uncertainty, and usefully managing uncertainty forces us to get good at warrant. For example, in
[the tournaments run by Philip Tetlock to see who is best at predicting the future](https://en.wikipedia.org/wiki/The_Good_Judgment_Project)
the winners tend to explore much more of the hypothesis space than the mediocre. Instead of examining one
possibility and prematurely narrowing things down to a handful of outcomes (all of which might be wrong)
they look at several possible outcomes and try to weigh their probability against each other. This sort of
thorough exploration helps us become more justified in our beliefs. Evaluating the relative likelihood of a
set of possibilities moves us beyond focusing on individual facts or ideas, and facilitates the creation of
consistent mental models of reality which can begin to suggest necessary conclusions.

Consider again the earlier questions about god. Christianity claims that those who don't give up their
mind and body to Christ will be eternally damned. This is a pretty scary idea, but it becomes a bit less
scary when we consider other theologies claiming much the same thing. Even in the Abrahamic family alone
we have Judaism, Christianity, and Islam which all mutually claim followers of the other two will meet their
end in the lake of fire. Just by considering all of the major world religions, we find the framing
attack James Kennedy uses to persuade less compelling. 

The failure of warrant is also behind one of the more important design flaws in modern republics:
focusing control mechanisms on the *consideration* of new laws rather than the *proposal* of new laws.
In theory a republic is meant to be kept in check by allowing competing interests at the table, which
prevents one segment of society from unfairly appropriating state power to enrich and elevate itself
over others. The [typical implementation of this](https://www.oregonlegislature.gov/citizen_engagement/Pages/How-an-Idea-Becomes-Law.aspx) 
assumes that ideas for new laws appear because of "concerned citizens", and the process doesn't focus too
much on the origins or justifications for laws. In the context of information theory, this is a recipe for
disaster. If simply proposing a question takes us most of the way to saying "yes", then in practice what
we've done with this ruleset is leave most of the power of making laws almost completely unregulated and uncontrolled.
Bad actors can re-propose their unpopular initiatives until they get the right
set of circumstances for them to pass.

## Principles Of Warrant

[The last time I talked about warrant](https://www.greaterwrong.com/posts/pC74aJyCRgns6atzu/meta-discussion-from-circling-as-cousin-to-rationality#comment-c7Xt5AnHwhfgYY67K)
I avoided precisely defining what makes a question worth considering, pushing the matter out to social consensus.
But the worthiness of questions exists independently of social approval. To think clearly even when
those around us don't requires some kind of objective standard. In her *Intellectual Foundation Of Information Organization*,
Elaine Svenonius deals with questions of this sort often in the context of library science. To figure out which features
should be part of a biobliographic record, she lays out *principles of warrant* and uses them as criteria to 
justify the inclusion or exclusion of information. We can do something similar, but because 'asking questions' is such
a broad thing it's not really possible to write out a complete set of principles. Rather I suspect that [the Pareto Rule](https://en.wikipedia.org/wiki/Pareto_principle)
is in play and expecting *any justification* for questions does most of the work for us. Still, there are some principles
of warrant that come to mind:

### Principle Of Confusion

If two or more trustworthy models predict contradictory outcomes, [you are confused about a subject](https://www.readthesequences.com/Noticing-Confusion-Sequence)
and should be asking what the source of contradiction is. 

#### Principle Of Priors

When we expect something to be true and find that observation or inference implies it isn't,
[we should notice we're confused](https://www.readthesequences.com/Your-Strength-As-A-Rationalist) and ask questions.

### Principle Of Pain

Empirical observation of problems is a good reason to ask questions about why they occur and how they can be
stopped.

### Principle Of Relation

If you're already asking a question, it's often warranted to ask questions which are closeby in question-space.
Be wary however that the principle of relation is fairly weak, and [six degrees of kevin bacon](https://en.wikipedia.org/wiki/Six_Degrees_of_Kevin_Bacon)
means that it can be used adversarially to shoehorn discussion of topics which wouldn't otherwise come up.

### Principle Of Balance

When you ask a question, it's also often useful to ask its inverse.

### Principle Of Exhaustion

If a question can be interpreted as belonging to a meaningful category, asking other questions in the same category can be
useful to compare answers/etc.

This list is obviously not exhaustive, and memorizing it wouldn't be a good strategy for getting good at warrant. 
Using warrant in practice is more like imagining some sense-data you would like to see. For example, if you're 
[reviewing the literature](https://guides.library.harvard.edu/c.php?g=310271&p=2071512) on the procedure
to induce Haitian voodoo spirit possession, what you're really asking is a question like "Where in the world would
I look to find information on this? Who would know about it? Where has information been left behind by the presence of
this phenomena?". You might try anthropological accounts of voodoo practices, or hit up YouTube to see if an inconsiderate
tourist has filmed the proceedings (or a nosy anthropologist). Getting good at thinking about where a phenomena would leave
traces in the world lets you remove [degrees of freedom](https://en.wikipedia.org/wiki/Degrees_of_freedom) from your beliefs
until they're tightly constrained by empirical observation; that is to say they have become thoroughly justified.

