Title: On Necessity
Authors: namespace, Hivewired
Date: 2020-03-23
Category: Essay


<blockquote>There are two ways to slide easily through life: Namely, to believe everything, or to doubt everything; both ways save us from thinking.
<br><br>&nbsp;&nbsp;&nbsp;&nbsp;— Alfred Korzybski, <i><a href="https://www.gutenberg.org/files/25457/25457-pdf.pdf">The Manhood of Humanity</a></i>
</blockquote>
 
For most of human history, cultures and individuals held to the idea that there was one truth that could be discovered or divined. While different tribes and traditions might disagree strongly on whose truth was correct, no one particularly objected to the idea that there was a truth to the world which you either had or did not have. Both the priest and the shaman believed their worldviews were correct, but neither one of them put stock in the notion that they were both somehow correct. Contradictory statements could not both be true, someone was right and someone was wrong. In the contemporary era this has begun to change, and not for the better:

<blockquote>
Eclecticism may be defined as the practice of choosing apparently irreconcilable doctrines from antagonistic schools and constructing therefrom a composite philosophic system in harmony with the convictions of the eclectic himself. Eclecticism can scarcely be considered philosophically or logically sound, for as individual schools arrive at their conclusions by different methods of reasoning, so the philosophic product of fragments from these schools must necessarily be built upon the foundation of conflicting premises. Eclecticism, accordingly, has been designated the layman's cult. In the Roman Empire little thought was devoted to philosophic theory; consequently most of its thinkers were of the eclectic type. Cicero is the outstanding example of early Eclecticism, for his writings are a veritable potpourri of invaluable fragments from earlier schools of thought. Eclecticism appears to have had its inception at the moment when men first doubted the possibility of discovering ultimate truth. Observing all so-called knowledge to be mere opinion at best, the less studious furthermore concluded that the wiser course to pursue was to accept that which appeared to be the most reasonable of the teachings of any school or individual. From this practice, however, arose a pseudo-broadmindedness devoid of the element of preciseness found in true logic and philosophy.
<br><br>&nbsp;&nbsp;&nbsp;&nbsp; — Manly P. Hall, <i><a href="https://archive.org/details/TheSecretTeachingsOfAllAgesManlyHall/">The Secret Teachings Of All Ages</a></i>
</blockquote>

Eclecticism and its descendent postmodernism raise the idea that the ultimate truth of the world can never really be known. The world is subjective down to its roots, reality is just like, your opinion man. This has had disastrous effects on the wider pursuit of truth. Hard science has been inundated by limp wristed subjectivity and the notion of a plurality of contradictory truths all being correct has become the norm across much of the humanities. How could a proper art and science of human engineering ever come out of this potpourri of nonsense?

You can’t design a bridge without actually knowing the tensile strength of steel and the compressive strength of concrete, these facts are not open to interpretation. Designing a society is no different and pretending that all viewpoints are equal, that all truths are just as valid as one another, is a dangerous precedent that has brought development of the humanities to a screeching halt. If we truly want to advance the art of rationality, this notion must be stamped out with extreme prejudice. 

This is easily the most important concept that Eliezer discusses in The Sequences. Reality actually exists and has properties you can determine through study and experimentation. Conclusions follow from their premises and it’s unreasonable to expect a plurality of truths. Our universe is consistent and your understanding of the pieces should fit together. The truth isn’t just your opinion. There is one truth and you find it or you don’t:

<blockquote>
But it was Probability Theory that did the trick. Here was probability theory, laid out not as a clever tool, but as The Rules, inviolable on pain of paradox. If you tried to approximate The Rules because they were too computationally expensive to use directly, then, no matter how necessary that compromise might be, you would still end up doing less than optimal. Jaynes would do his calculations different ways to show that the same answer always arose when you used legitimate methods; and he would display different answers that others had arrived at, and trace down the illegitimate step. Paradoxes could not coexist with his precision. Not an answer, but the answer.
</blockquote>

The universe operates on rules, and the rules continue to apply to you whether you believe in them or not. The rules are not optional, they are not open to interpretation, they do not care about your feelings. The universe exists, and it cannot be negotiated around. That’s not fair? Doesn’t matter. But that’s injust! Doesn’t matter. But—

<blockquote>
What can a twelfth-century peasant do to save themselves from annihilation? Nothing. Nature’s little challenges aren’t always fair. When you run into a challenge that’s too difficult, you suffer the penalty; when you run into a lethal penalty, you die. That’s how it is for people, and it isn’t any different for planets. Someone who wants to dance the deadly dance with Nature does need to understand what they’re up against: Absolute, utter, exceptionless neutrality.
</blockquote>

Eliezer discusses this mostly in the context of physics and Bayesian reasoning. If conclusions follow from their premises, and the premises always lead to the same conclusion, we can say that conclusion is *necessary*. Valid methods of thinking will reliably produce the same answer (modulo some noise in real world thinkers) given the same priors and evidence. Two and two make four, matter cannot be created or destroyed, the probability of two independent events occurring is always less than the independent probability of either. Curiously, necessity is discussed frequently in The Sequences but never given a name. This is to their detriment, as necessity is one of the hardest concepts in rationality to master.

Most basic failures of rationality are some form of refusal of necessity. This is unsurprising, because necessity is the dream killer. As children [we dream of being veterinarians, astronauts and mad scientists](https://www.reed.co.uk/career-advice/revealed-what-your-kids-really-want-to-be-when-they-grow-up/), not the lawyers, accountants, and grocery store clerks we actually grow up to be. We’re told all sorts of things about the world and ourselves that we don’t want to hear, so we deny them. Everyone else might have to get a job but not *me*, when I’m older I’ll eat *all the candy I want*, I’m not going to die. Over time, this reflex becomes automatic and we stop even noticing the denial. 

For example I recently saw a discussion of necessity on a ‘rationalist’ forum where someone pointed out that it was impossible to fly unassisted. A Buddhist replied that it was only impossible to fly unassisted in consensus reality. They argued that it’s possible to fly in a lucid dream, so their real complaint is that they can’t do it where it will affect others. The entire process of thought that is capable of generating this objection betrays an extreme level of disassociation; where the default is a personal, private universe separated from the underlying physics which allow it to exist. That dream world is the thing necessity takes away from us, what people are afraid of losing by [restricting themselves to what is there to be experienced in reality](https://www.greaterwrong.com/posts/x4dG4GhpZH2hgz59x/joy-in-the-merely-real). The refusal of necessity is synonymous with the refusal of reality, which Buddhism provides a framework for. In Buddhism, the aspiring Arhat dismantles their attachments to the material world and turns their survival hardware into a substrate to run a personal paradise for a certain amount of time before being annihilated into a welcomed nothingness. This is one way of dealing with the problem of necessity, but it’s not one we can sanely endorse and still consider ourselves rationalists.

Our private symbolic universe is not the only thing we’re looking to guard by refusing necessity. Often we resent the effort we’d have to go through if we took our beliefs seriously, supported by an implicit meta-belief that life should never be too hard. In many ways, a 1st world childhood is a very bad introduction to life because it sets you up for a lifetime of unreasonable expectations. 
Conditions are so good that it becomes easy to imagine in our childish naivete that life can be an indefinite sleepwalk through an introvert’s dream world or a never ending play session in an extrovert’s favorite field. Eventually we are pulled away from these delusions, but the expectations set by that tutorial stay with us for life. Bennett Foddy [writes about the process](https://www.youtube.com/watch?v=IO6ouSMm7Uc) of building a game meant to show players their unreasonable expectations about challenge and difficulty:

<blockquote>
Anyway when you start Sexy Hiking, you’re standing next to this dead tree that blocks the way to the entire rest of the game. It might take you an hour to get over that tree, and a lot of people never got past it, you prod and you poke at it exploring the limits of your reach and strength trying to find a way up and over. And there’s a sense of truth in that lack of compromise. Most obstacles in video game worlds are fake, you can be completely confident in your ability to get through them, once you have the correct method or the correct equipment or just by spending enough time. In that sense, every pixelated obstacle in Sexy Hiking is real
<br><br>
. . .
<br><br>
A funny thing happened to me as I was building this mountain. I’d have an idea for a new obstacle, and I’d build it, test it, and I would usually find it was unreasonably hard. But I couldn’t bring myself to make it any easier, it already felt like my inability to get past the new obstacle was my fault as a player rather than as the builder.
</blockquote>

I heard a story from the recent COVID-19 outbreak that illustrates this well. A man living with relatives noticed they were still buying bananas from the grocery. When he inquired about whether they’d been washed to prevent the spread of COVID-19, he got a very strange answer. They had not been washed, but that was okay because bananas had a skin on them. The relatives insisted he should peel the banana and then carefully avoid letting the outside peel touch the meat of the fruit on the inside. So long as he didn’t touch it with his fingers then he wouldn’t be putting his face in contact with the virus. This is the sort of thing you think is okay when you aren’t taking ideas seriously. He wasn’t very hungry for bananas after that. 

At the core of the difficulty people have with necessity is uncertainty. It’s obvious that two and two make four, but when things become less obvious than that, [when they get abstract or there’s incomplete information suddenly magical thinking gets introduced](https://www.greaterwrong.com/posts/zFuCxbY9E2E8HTbfZ/perpetual-motion-beliefs). Our biases take over, and whether in the direction of pessimism or optimism our beliefs become hallucinations premised on a smaller and smaller proportion of evidence to analysis and speculation. What Eliezer tries to get across with his insistence on a Bayesian foundation for epistemology is that your beliefs should still be necessary even under conditions of uncertainty. It is the duty of every serious philosopher to learn to *feel gradations of necessity* and to intuit how necessary their beliefs are. What degrees of freedom remain in their ideas, what hypotheses are still left to be considered, exactly how much weight does it make sense to put on a given hypothesis given the available evidence? There are exact, precise answers to these questions even if they are outside of your current awareness.

Failing to accept the world as it is, failing to take ideas seriously, makes us a danger to ourselves and others. In this the current pandemic gives us a rather fantastic (albeit horrifying) window into the limits of the dream worlds that most people inhabit. College students [openly defy public health experts because they’re entitled to spring break](https://www.washingtonpost.com/nation/2020/03/19/coronavirus-spring-break-party/). The health minister of Iran [gets the virus and still insists that quarantine is an outdated method of controlling an epidemic](https://www.france24.com/en/20200225-iran-iraj-harirchi-coronavirus-deputy-health-minister). President Trump [tells the public that the disease is comparable to the flu until it’s too late for us to contain it](https://www.vox.com/policy-and-politics/2020/3/13/21176535/trumps-worst-statements-coronavirus). If this were a movie it’d be panned by critics as unrealistic b-film trash.

<img src="theme/images/trump_statements_vs_covid_19_cases.png" width=75% height=75%>

It’s quite impressive how far people will go to protect their worldview at the cost of their wellbeing, but even this has its limits. Eventually too much predictive error will build up and the whole edifice will come crashing down. What will it take to make you look? How much harm do you have to come to? How many [people close to you have to die](http://yudkowsky.net/other/yehuda/) before you’ll actually look at the world as it is? Over the coming weeks, [we can expect to see](https://medium.com/@tomaspueyo/coronavirus-act-today-or-people-will-die-f4d3d9cd99ca) a lot of deeply held worldviews fracture as the illusion of safety is rudely torn away. The safety blanket of childhood won’t protect you from bullets or viruses, [only true knowledge of the universe has any hope of doing that](https://www.youtube.com/watch?v=xXXF2C-vrQE).

You can get a lot of mileage out of willful ignorance, but eventually your fake beliefs will come back to bite you. For example, in the Iranian city of Qom, a number of religious shrines remained open and busy even as the coronavirus tore through the city, because religious leaders believed the shrines had magical healing properties. They don’t. Iran is now digging mass graves. When magical beliefs come up against the cold face of unflinching reality, reality wins. Thus, in order to protect these magical beliefs they have to be socially insulated from reality, challenging them has to be verboten. However when this happens, from the outside it looks rather obvious that the deck is being stacked against truth, and it can’t hold up forever. However uncomfortable the truth may be, as a certain mad titan says, you can dread it, run from it, but destiny arrives all the same. 

Most people are familiar with [the incident where Catholicism lost credibility](https://en.wikipedia.org/wiki/Galileo_affair) by insisting that the sun revolved around the earth when it did not. I suspect that part of why we single out this episode as a decisive triumph of science over religion is that it represents more than just the loss of Catholicism’s control of cosmology. Rather, it is a prelude to the more personal and uncomfortable revelation that humanity is not the center of the universe. We are a marginal force in nature which exists on a ‘pale blue dot’, and the rest of creation stretches out for an unfathomable distance around us. It is when we fully internalize this, along with Darwin’s revelation that humanity is a product of nature and arose from adaption to the natural world (including other humans, who are also part of the natural world) that we understand [the absurdity of denying death](https://www.thelastrationalist.com/memento-mori-said-the-confessor.html). 

<blockquote>
In the what-if world where every step follows only from the cellular automaton rules, the equivalent of Genghis Khan can murder a million people, and laugh, and be rich, and never be punished, and live his life much happier than the average.  Who prevents it?
</blockquote>

Were it “within the stars” so to speak, nature would discard us like you discard so many used tissues. Life is not sacred to the universe, let alone human life. If sleeping [really did end your thread of experience](http://www.existentialcomics.com/comic/1) nature would have no problem letting that happen. It would allow you to die thousands of deaths over the course of your life so long as it made no difference to reproduction. Observing this vast cosmos and the amoral gears of creation, it becomes abundantly obvious that there is no afterlife. Nature, which seems to care about nothing else and has seen fit to save nothing else, has almost certainly not set aside a special preserve for the sake of your experiences and feelings. You are not special in the eyes of creation, you are a blob of animate matter that will one day become a blob of inanimate matter and that is that. In the second law of thermodynamics, the house always wins; at best you can hope for some unforeseen development in physics which allows us to defeat entropy. In the meantime, there is no life after this one. The expectation that you will see lost loved ones in the hereafter, that you will have eternal life through Jesus Christ, that when you die you will wake again from your lifelong dream is unreasonable.

Your expectation of eternal life has always been unreasonable, nothing else lasts forever: why would you?
